==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkBoxWidget.java <==
// java wrapper for vtkBoxWidget object
//

package vtk;
import vtk.*;

public class vtkBoxWidget extends vtk3DWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void PlaceWidget_3(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_3(id0); }

  private native void PlaceWidget_4();
  public void PlaceWidget()
    { PlaceWidget_4(); }

  private native void PlaceWidget_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void PlaceWidget(double id0,double id1,double id2,double id3,double id4,double id5)
    { PlaceWidget_5(id0,id1,id2,id3,id4,id5); }

  private native void GetPlanes_6(vtkPlanes id0);
  public void GetPlanes(vtkPlanes id0)
    { GetPlanes_6(id0); }

  private native void SetInsideOut_7(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_7(id0); }

  private native int GetInsideOut_8();
  public int GetInsideOut()
    { return GetInsideOut_8(); }

  private native void InsideOutOn_9();
  public void InsideOutOn()
    { InsideOutOn_9(); }

  private native void InsideOutOff_10();
  public void InsideOutOff()
    { InsideOutOff_10(); }

  private native void GetTransform_11(vtkTransform id0);
  public void GetTransform(vtkTransform id0)
    { GetTransform_11(id0); }

  private native void SetTransform_12(vtkTransform id0);
  public void SetTransform(vtkTransform id0)
    { SetTransform_12(id0); }

  private native void GetPolyData_13(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_13(id0); }

  private native long GetHandleProperty_14();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_14();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedHandleProperty_15();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_15();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void HandlesOn_16();
  public void HandlesOn()
    { HandlesOn_16(); }

  private native void HandlesOff_17();
  public void HandlesOff()
    { HandlesOff_17(); }

  private native long GetFaceProperty_18();
  public vtkProperty GetFaceProperty() {
    long temp = GetFaceProperty_18();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedFaceProperty_19();
  public vtkProperty GetSelectedFaceProperty() {
    long temp = GetSelectedFaceProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetOutlineProperty_20();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_20();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedOutlineProperty_21();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_21();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetOutlineFaceWires_22(int id0);
  public void SetOutlineFaceWires(int id0)
    { SetOutlineFaceWires_22(id0); }

  private native int GetOutlineFaceWires_23();
  public int GetOutlineFaceWires()
    { return GetOutlineFaceWires_23(); }

  private native void OutlineFaceWiresOn_24();
  public void OutlineFaceWiresOn()
    { OutlineFaceWiresOn_24(); }

  private native void OutlineFaceWiresOff_25();
  public void OutlineFaceWiresOff()
    { OutlineFaceWiresOff_25(); }

  private native void SetOutlineCursorWires_26(int id0);
  public void SetOutlineCursorWires(int id0)
    { SetOutlineCursorWires_26(id0); }

  private native int GetOutlineCursorWires_27();
  public int GetOutlineCursorWires()
    { return GetOutlineCursorWires_27(); }

  private native void OutlineCursorWiresOn_28();
  public void OutlineCursorWiresOn()
    { OutlineCursorWiresOn_28(); }

  private native void OutlineCursorWiresOff_29();
  public void OutlineCursorWiresOff()
    { OutlineCursorWiresOff_29(); }

  private native void SetTranslationEnabled_30(int id0);
  public void SetTranslationEnabled(int id0)
    { SetTranslationEnabled_30(id0); }

  private native int GetTranslationEnabled_31();
  public int GetTranslationEnabled()
    { return GetTranslationEnabled_31(); }

  private native void TranslationEnabledOn_32();
  public void TranslationEnabledOn()
    { TranslationEnabledOn_32(); }

  private native void TranslationEnabledOff_33();
  public void TranslationEnabledOff()
    { TranslationEnabledOff_33(); }

  private native void SetScalingEnabled_34(int id0);
  public void SetScalingEnabled(int id0)
    { SetScalingEnabled_34(id0); }

  private native int GetScalingEnabled_35();
  public int GetScalingEnabled()
    { return GetScalingEnabled_35(); }

  private native void ScalingEnabledOn_36();
  public void ScalingEnabledOn()
    { ScalingEnabledOn_36(); }

  private native void ScalingEnabledOff_37();
  public void ScalingEnabledOff()
    { ScalingEnabledOff_37(); }

  private native void SetRotationEnabled_38(int id0);
  public void SetRotationEnabled(int id0)
    { SetRotationEnabled_38(id0); }

  private native int GetRotationEnabled_39();
  public int GetRotationEnabled()
    { return GetRotationEnabled_39(); }

  private native void RotationEnabledOn_40();
  public void RotationEnabledOn()
    { RotationEnabledOn_40(); }

  private native void RotationEnabledOff_41();
  public void RotationEnabledOff()
    { RotationEnabledOff_41(); }

  public vtkBoxWidget() { super(); }

  public vtkBoxWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkBoxWidget.java <==
// java wrapper for vtkBoxWidget object
//

package vtk;
import vtk.*;

public class vtkBoxWidget extends vtk3DWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void PlaceWidget_3(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_3(id0); }

  private native void PlaceWidget_4();
  public void PlaceWidget()
    { PlaceWidget_4(); }

  private native void PlaceWidget_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void PlaceWidget(double id0,double id1,double id2,double id3,double id4,double id5)
    { PlaceWidget_5(id0,id1,id2,id3,id4,id5); }

  private native void GetPlanes_6(vtkPlanes id0);
  public void GetPlanes(vtkPlanes id0)
    { GetPlanes_6(id0); }

  private native void SetInsideOut_7(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_7(id0); }

  private native int GetInsideOut_8();
  public int GetInsideOut()
    { return GetInsideOut_8(); }

  private native void InsideOutOn_9();
  public void InsideOutOn()
    { InsideOutOn_9(); }

  private native void InsideOutOff_10();
  public void InsideOutOff()
    { InsideOutOff_10(); }

  private native void GetTransform_11(vtkTransform id0);
  public void GetTransform(vtkTransform id0)
    { GetTransform_11(id0); }

  private native void SetTransform_12(vtkTransform id0);
  public void SetTransform(vtkTransform id0)
    { SetTransform_12(id0); }

  private native void GetPolyData_13(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_13(id0); }

  private native long GetHandleProperty_14();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_14();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedHandleProperty_15();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_15();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void HandlesOn_16();
  public void HandlesOn()
    { HandlesOn_16(); }

  private native void HandlesOff_17();
  public void HandlesOff()
    { HandlesOff_17(); }

  private native long GetFaceProperty_18();
  public vtkProperty GetFaceProperty() {
    long temp = GetFaceProperty_18();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedFaceProperty_19();
  public vtkProperty GetSelectedFaceProperty() {
    long temp = GetSelectedFaceProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_20();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_20();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_21();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_21();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutlineFaceWires_22(int id0);
  public void SetOutlineFaceWires(int id0)
    { SetOutlineFaceWires_22(id0); }

  private native int GetOutlineFaceWires_23();
  public int GetOutlineFaceWires()
    { return GetOutlineFaceWires_23(); }

  private native void OutlineFaceWiresOn_24();
  public void OutlineFaceWiresOn()
    { OutlineFaceWiresOn_24(); }

  private native void OutlineFaceWiresOff_25();
  public void OutlineFaceWiresOff()
    { OutlineFaceWiresOff_25(); }

  private native void SetOutlineCursorWires_26(int id0);
  public void SetOutlineCursorWires(int id0)
    { SetOutlineCursorWires_26(id0); }

  private native int GetOutlineCursorWires_27();
  public int GetOutlineCursorWires()
    { return GetOutlineCursorWires_27(); }

  private native void OutlineCursorWiresOn_28();
  public void OutlineCursorWiresOn()
    { OutlineCursorWiresOn_28(); }

  private native void OutlineCursorWiresOff_29();
  public void OutlineCursorWiresOff()
    { OutlineCursorWiresOff_29(); }

  private native void SetTranslationEnabled_30(int id0);
  public void SetTranslationEnabled(int id0)
    { SetTranslationEnabled_30(id0); }

  private native int GetTranslationEnabled_31();
  public int GetTranslationEnabled()
    { return GetTranslationEnabled_31(); }

  private native void TranslationEnabledOn_32();
  public void TranslationEnabledOn()
    { TranslationEnabledOn_32(); }

  private native void TranslationEnabledOff_33();
  public void TranslationEnabledOff()
    { TranslationEnabledOff_33(); }

  private native void SetScalingEnabled_34(int id0);
  public void SetScalingEnabled(int id0)
    { SetScalingEnabled_34(id0); }

  private native int GetScalingEnabled_35();
  public int GetScalingEnabled()
    { return GetScalingEnabled_35(); }

  private native void ScalingEnabledOn_36();
  public void ScalingEnabledOn()
    { ScalingEnabledOn_36(); }

  private native void ScalingEnabledOff_37();
  public void ScalingEnabledOff()
    { ScalingEnabledOff_37(); }

  private native void SetRotationEnabled_38(int id0);
  public void SetRotationEnabled(int id0)
    { SetRotationEnabled_38(id0); }

  private native int GetRotationEnabled_39();
  public int GetRotationEnabled()
    { return GetRotationEnabled_39(); }

  private native void RotationEnabledOn_40();
  public void RotationEnabledOn()
    { RotationEnabledOn_40(); }

  private native void RotationEnabledOff_41();
  public void RotationEnabledOff()
    { RotationEnabledOff_41(); }

  public vtkBoxWidget() { super(); }

  public vtkBoxWidget(long id) { super(id); }
  public native long   VTKInit();

}
